@@ -8,6 +8,13 @@
 #' and `j`. If you use i = c(1,3) and j = c(2,5), then you will
 #' add the symbols (or the repeated symbol) to cells `[1,2]`
 #' and `[3,5]`.
+#'
+#' \if{html}{\out{
+#' <img src="https://www.ardata.fr/img/flextable-imgs/flextable-016.png" alt="add_footer illustration" style="width:100\%;">
+#'
+#' See https://www.ardata.fr/en/flextable-gallery/2022-06-23-separate-headers/ for the example
+#' shown
+#' }}
 #' @param x a flextable object
 #' @param i,j cellwise rows and columns selection
 #' @param value a call to function [as_paragraph()].
@@ -19,33 +26,45 @@
 #' a separator between footnotes.
 #' @examples
 #' ft_1 <- flextable(head(iris))
-#' ft_1 <- footnote( ft_1, i = 1, j = 1:3,
-#'             value = as_paragraph(
-#'               c("This is footnote one",
-#'                 "This is footnote two",
-#'                 "This is footnote three")
-#'             ),
-#'             ref_symbols = c("a", "b", "c"),
-#'             part = "header")
+#' ft_1 <- footnote(ft_1,
+#'   i = 1, j = 1:3,
+#'   value = as_paragraph(
+#'     c(
+#'       "This is footnote one",
+#'       "This is footnote two",
+#'       "This is footnote three"
+#'     )
+#'   ),
+#'   ref_symbols = c("a", "b", "c"),
+#'   part = "header"
+#' )
 #' ft_1 <- valign(ft_1, valign = "bottom", part = "header")
 #' ft_1 <- autofit(ft_1)
 #'
 #' ft_2 <- flextable(head(iris))
 #' ft_2 <- autofit(ft_2)
-#' ft_2 <- footnote( ft_2, i = 1, j = 1:2,
-#'                value = as_paragraph(
-#'                 c("This is footnote one",
-#'                    "This is footnote two")
-#'                ),
-#'                ref_symbols = c("a", "b"),
-#'                part = "header", inline = TRUE)
-#' ft_2 <- footnote( ft_2, i = 1, j = 3:4,
-#'                value = as_paragraph(
-#'                  c("This is footnote three",
-#'                    "This is footnote four")
-#'                ),
-#'                ref_symbols = c("c","d"),
-#'                part = "header", inline = TRUE)
+#' ft_2 <- footnote(ft_2,
+#'   i = 1, j = 1:2,
+#'   value = as_paragraph(
+#'     c(
+#'       "This is footnote one",
+#'       "This is footnote two"
+#'     )
+#'   ),
+#'   ref_symbols = c("a", "b"),
+#'   part = "header", inline = TRUE
+#' )
+#' ft_2 <- footnote(ft_2,
+#'   i = 1, j = 3:4,
+#'   value = as_paragraph(
+#'     c(
+#'       "This is footnote three",
+#'       "This is footnote four"
+#'     )
+#'   ),
+#'   ref_symbols = c("c", "d"),
+#'   part = "header", inline = TRUE
+#' )
 #' ft_2
 #'
 #' ft_3 <- flextable(head(iris))
@@ -60,9 +79,12 @@
 #' @importFrom stats update
 footnote <- function(x, i = NULL, j = NULL, value, ref_symbols = NULL, part = "body",
                      inline = FALSE, sep = "; ") {
-  if( !inherits(x, "flextable") ) {
+  if (!inherits(x, "flextable")) {
     stop(sprintf("Function `%s` supports only flextable objects.", "footnote()"))
   }
+  if (!inherits(value, "paragraph")) {
+    stop("`value` must be a paragraph.")
+  }
 
   part <- match.arg(part, c("body", "header", "footer"),
     several.ok = FALSE
@@ -82,13 +104,13 @@ footnote <- function(x, i = NULL, j = NULL, value, ref_symbols = NULL, part = "b
     symbols_str <- ref_symbols
   }
 
-  if(any(ref_symbols %in% "")) {
-    long_msg <- c("Usage of empty symbol '' with footnote should not happen, ",
-         "use `add_footer_lines()` instead, it does not require any symbol. ",
-         "This usage will be forbidden in the next release. Please, wait for 10 seconds!")
+  if (any(symbols_str %in% "")) {
+    long_msg <- c(
+      "Usage of empty symbol '' with footnote should not happen, ",
+      "use `add_footer_lines()` instead, it does not require any symbol. "
+    )
     long_msg <- paste0(long_msg, collapse = "\n")
-    message(long_msg)
-    Sys.sleep(10)
+    stop(long_msg)
   }
 
   sep_str <- rep(sep, length(value))
@@ -111,15 +133,19 @@ footnote <- function(x, i = NULL, j = NULL, value, ref_symbols = NULL, part = "b
     )
   }
 
-  n_row <- nrow_part(x, "footer")
+
 
   if (inline) {
     # init a new line
-    if (n_row < 1) {
+    if (nrow_part(x, "footer") < 1) {
       x <- add_footer_lines(x, values = "")
-      n_chunk <- 0
+      n_row <- 1
     } else {
-      n_chunk <- nrow(x[["footer"]]$content[n_row, 1][[1]])
+      n_row <- nrow_part(x, "footer")
+      target_par <- get_fpstruct_elements(
+        x = x[["footer"]]$content,
+        i = n_row,
+        j = 1)[[1,1]]
     }
 
     paras <- mapply(rbind,
@@ -128,24 +154,33 @@ footnote <- function(x, i = NULL, j = NULL, value, ref_symbols = NULL, part = "b
       as_paragraph(sep_str),
       SIMPLIFY = FALSE
     )
-    paras <- do.call(rbind, paras)
-    paras$seq_index <- seq_len(nrow(paras)) + n_chunk
-    if (n_row < 1) {
-      x[["footer"]]$content[1, 1] <- list(paras)
-    } else {
-      x[["footer"]]$content[n_row, 1] <- list(rbind(x[["footer"]]$content[n_row, 1][[1]], paras))
+    paras <- rbind_match_columns(paras)
+    paras$.chunk_index <- NULL
+    for(i in seq_len(nrow(paras))) {
+      x[["footer"]]$content <-
+        append_chunkset_struct_element(
+          x = x[["footer"]]$content,
+          i = n_row,
+          j = 1,
+          chunk_data = paras[i,]
+        )
     }
-
   } else {
     # init new lines
-    x <- add_footer_lines(x, values = ref_symbols)
+    n_row <- nrow_part(x, "footer")
+    x <- add_footer_lines(x, values = rep("", length(value)))
+    newcontent <- as_chunkset_struct(
+      l_paragraph = value, keys = x$col_keys[1])
+    x[["footer"]]$content <- set_chunkset_struct_element(
+      x = x[["footer"]]$content,
+      i = n_row + seq_along(value), j = 1,
+      value = newcontent
+    )
     for (v in seq_along(value)) {
-      # `[<-.chunkset_struct`
-      x[["footer"]]$content[n_row + v, j = 1] <- value[v]
       x <- prepend_chunks(
         x = x, i = n_row + v, j = 1,
         part = "footer",
-        as_sup(ref_symbols[v])# [ as we want a list of df
+        as_sup(symbols_str[v])
       )
     }
   }
