@@ -8,13 +8,17 @@
 #' library(flextable)
 #' ft <- qflextable(head(cars))
 #' nrow_part(ft, part = "body")
-nrow_part <- function(x, part = "body"){
-  if( !inherits(x, "flextable") ) stop("nrow_part supports only flextable objects.")
-  if( is.null(x[[part]]) )
+nrow_part <- function(x, part = "body") {
+  if (!inherits(x, "flextable")) {
+    stop(sprintf("Function `%s` supports only flextable objects.", "nrow_part()"))
+  }
+  if (is.null(x[[part]])) {
     0
-  else if( is.null(x[[part]]$dataset) )
+  } else if (is.null(x[[part]]$dataset)) {
     0
-  else nrow(x[[part]]$dataset)
+  } else {
+    nrow(x[[part]]$dataset)
+  }
 }
 
 #' @export
@@ -26,7 +30,9 @@ nrow_part <- function(x, part = "body"){
 #' library(flextable)
 #' ft <- qflextable(head(cars))
 #' ncol_keys(ft)
-ncol_keys <- function(x){
-  if( !inherits(x, "flextable") ) stop("ncol_keys supports only flextable objects.")
+ncol_keys <- function(x) {
+  if (!inherits(x, "flextable")) {
+    stop(sprintf("Function `%s` supports only flextable objects.", "ncol_keys()"))
+  }
   length(x$col_keys)
 }
